/* 
 * PPRacer 
 * Copyright (C) 2004 Volker Stroebel <volker@planetpenguin.de>
 *
 * Copyright (C) 1999-2001 Jasmin F. Patry
 * 
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 */

#ifndef _FONTS_H_
#define _FONTS_H_

#include "ppracer.h"

#include "tex_font_metrics.h"
#include "textures.h"

#include "ppgltk/alg/color.h"
#include "ppgltk/alg/vec2d.h"

#include <string>



typedef struct {
    tex_font_metrics_t *tfm;
    texture_node_t tex;
    int ref_count;
} font_node_t;

struct font_t {
    font_node_t *node;
    double size;
    pp::Color color;
};


void init_fonts();

bool load_font( const char *fontname, const char *filename, const char *texname );

bool bind_font( const char *binding, const char *fontname, double size, 
		  pp::Color color );
bool get_font_binding( const char *binding, font_t &font );
bool unbind_font( char *binding );

bool flush_fonts(void);

void bind_font_texture( font_t *font );
void draw_character( font_t *font, char c);
void draw_string( font_t *font, const char *string);
void draw_string_with_markup( font_t *font, char *string);
void get_font_metrics( font_t *font, const char *string,
		       int *width, int *max_ascent, int *max_descent);

void register_font_callbacks(Tcl_Interp *ip);





class Font
{
	font_t m_data;
	bool m_centerX, m_centerY;
	
public:
	Font(char* binding, bool centerX=false, bool centerY=false);
	~Font();

	void draw(const char* string, pp::Vec2d position);
	void draw(std::string& string, pp::Vec2d position);

	int getWidth(const char* string);
};

#endif // _FONTS_H_
